@@ -198,7 +198,7 @@ POOL_REPORT_CONFIG* get_config(int *nrows)
 	i++;
 
 	strncpy(status[i].name, "pool_passwd", POOLCONFIG_MAXNAMELEN);
-	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->pool_passwd);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->pool_passwd);
 	strncpy(status[i].desc, "file name of pool_passwd for md5 authentication", POOLCONFIG_MAXDESCLEN);
 	i++;
 
